TokenizationRepresentation
==========================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: TokenizationRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TokenizationRepresentation.extra_repr
      ~TokenizationRepresentation.from_tokenizer

   .. rubric:: Methods Documentation

   .. automethod:: extra_repr
   .. automethod:: from_tokenizer
